Somé UTF-8°

* One
* Two

<script type="text/javascript">alert("All your base are belong to us");</script>

<javascript:alert('scary stuff')>

[javascript link](javascript:alert('scary stuff2'))

[javascript link](javascript:alert\('scary stuff3'\))

Regular link [example](http://url.com/ "Title")